import { List, Modal } from 'antd';
import 'antd/dist/antd.css';
import React, { useContext, useEffect, useState } from 'react';
import { AnnotationListInfo } from '../../api';
import { userController } from '../../controllers';
import { useUnauthRedirect } from '../../hooks';
import { LoggedUserContext } from '../../contexts/LoggedUserContext';

interface ModalProps {
    onCancel: () => void;
    userId: string | undefined;
}

function UserDocumentsModal({ onCancel, userId }: ModalProps) {
    const redirecting = useUnauthRedirect('/login');
    const { role } = useContext(LoggedUserContext);
    const [annotations, setAnnotations] = useState<AnnotationListInfo[]>([]);

    const handleOk = () => {
        onCancel();
    };

    const handleCancel = () => {
        onCancel();
    };

    useEffect(() => {
        if (!redirecting && role === 'ADMINISTRATOR' && userId) {
            userController
                .userUserIdAnnotationsGet(userId)
                .then(({ data: { annotations } }) => {
                    setAnnotations(annotations || []);
                });
        }
    }, [userId, redirecting, role]);

    return (
        <Modal
            title="Dokumenty uživatele"
            onOk={handleOk}
            visible={true}
            onCancel={handleCancel}
            footer={[null]}
        >
            <List
                dataSource={annotations}
                size={'small'}
                grid={{ gutter: 10, column: 1 }}
                style={{ maxHeight: 400, overflowY: 'auto', overflowX: 'hidden' }}
                renderItem={(item) => (
                    <List.Item key={item.annotationId}>
                        <List.Item.Meta title={item.documentName} />
                    </List.Item>
                )}
            />
        </Modal>
    );
}

export default UserDocumentsModal;
